pub(crate) async fn store_self_keypair(
context: &Context,
signed_secret_key: &SignedSecretKey,
) -> Result<()>Expand description
Stores own keypair in the database and sets it as a default.
Fails if we already have a key, so it is not possible to have more than one key for new setups. Existing setups may still have more than one key for compatibility.